<template>
  <Dialog v-model="dialogVisible" :title="dialogTitle" width="50%">
    <el-form
      ref="formRef"
      v-loading="formLoading"
      :model="formData"
      :rules="formRules"
      label-width="120px"
    >
      <el-row>
        <el-col :span="24">
          <el-form-item label="认证地址" prop="loginUrl">
            <el-input v-model="formData.loginUrl" placeholder="请输认证地址"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="ClientId" prop="clientId">
            <el-input v-model="formData.clientId" placeholder="请输ClientId"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="ClientSecret" prop="clientSecret">
            <el-input v-model="formData.clientSecret" placeholder="请输ClientSecret"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="用户名" prop="username">
            <el-input v-model="formData.username" placeholder="请输用户名"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="密码" prop="password">
            <el-input v-model="formData.password" placeholder="请输密码"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="刷新频率" prop="refreshFreq">
            <el-input v-model="formData.refreshFreq" placeholder="请输刷新频率"/>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <template #footer>
      <el-button :disabled="formLoading" type="primary" @click="submitForm">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script lang="ts" setup>
import * as HttpTokenApi from '@/api/data/channel/http/token'
import { DICT_TYPE, getStrDictOptions, getBoolDictOptions } from '@/utils/dict'

defineOptions({name: 'HttpTokenForm'})

const {t} = useI18n() // 国际化
const message = useMessage() // 消息弹窗
const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  loginUrl: undefined,
  clientId: undefined,
  clientSecret: undefined,
  username: undefined,
  password: undefined,
  token: undefined,
  refreshFreq: undefined
})
const formRules = reactive({
  loginUrl: [{required: true, message: '登录地址不能为空', trigger: 'blur'}],
  username: [{required: true, message: '用户名不能为空', trigger: 'blur'}],
  password: [{required: true, message: '密码不能为空', trigger: 'blur'}],
  refreshFreq: [{required: true, message: '刷新频率不能为空', trigger: 'blur'}]
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number, apiId?: string) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  if (apiId) {
    formData.value.apiId = apiId
  }
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await HttpTokenApi.getHttpToken(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({open}) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  if (!formRef) return
  const valid = await formRef.value.validate()
  if (!valid) return
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as HttpTokenApi.HttpTokenVO
    if (formType.value === 'create') {
      await HttpTokenApi.createHttpToken(data)
      message.success(t('common.createSuccess'))
    } else {
      await HttpTokenApi.updateHttpToken(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    loginUrl: undefined,
    clientId: undefined,
    clientSecret: undefined,
    username: undefined,
    password: undefined,
    token: undefined,
    refreshFreq: undefined
  }
  formRef.value?.resetFields()
}
</script>
